==> apache-servicecomb-java-chassis-distribution-1.3.11-src.zip: apache-servicecomb-java-chassis-distribution-1.3.11-src/transports/transport-rest/transport-rest-client/src/main/java/org/apache/servicecomb/transport/rest/client/RestTransportClientManager.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.servicecomb.transport.rest.client;

import org.apache.servicecomb.foundation.vertx.VertxUtils;

import io.vertx.core.Vertx;

public final class RestTransportClientManager {
  public static final RestTransportClientManager INSTANCE = new RestTransportClientManager();

  // same instance in AbstractTranport. need refactor in future.
  private final Vertx transportVertx = VertxUtils.getOrCreateVertxByName("transport", null);

  private RestTransportClient restClient;

  private RestTransportClientManager() {
    try {
      restClient = TransportClientConfig.getRestTransportClientCls().newInstance();
      restClient.init(transportVertx);
    } catch (Exception e) {
      throw new IllegalStateException("Failed to init RestTransportClient.", e);
    }
  }

  public RestTransportClient getRestClient() {
    return restClient;
  }
}

==> apache-servicecomb-java-chassis-distribution-2.8.16-src.zip: apache-servicecomb-java-chassis-distribution-2.8.16-src/transports/transport-rest/transport-rest-client/src/main/java/org/apache/servicecomb/transport/rest/client/RestTransportClientManager.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.servicecomb.transport.rest.client;

import org.apache.servicecomb.foundation.vertx.VertxUtils;

import io.vertx.core.Vertx;

public final class RestTransportClientManager {
  public static final RestTransportClientManager INSTANCE = new RestTransportClientManager();

  // same instance in AbstractTransport. need refactor in future.
  private final Vertx transportVertx = VertxUtils.getOrCreateVertxByName("transport", null);

  private final RestTransportClient restClient;

  private RestTransportClientManager() {
    try {
      restClient = TransportClientConfig.getRestTransportClientCls().getDeclaredConstructor().newInstance();
      restClient.init(transportVertx);
    } catch (Exception e) {
      throw new IllegalStateException("Failed to init RestTransportClient.", e);
    }
  }

  public RestTransportClient getRestClient() {
    return restClient;
  }
}
